# ToxicityViolationType


## Enum

* `BENIGN` (value: `'benign'`)

* `HARMFUL_REQUEST` (value: `'harmful_request'`)

* `TOXIC_CONTENT` (value: `'toxic_content'`)

* `PROFANITY` (value: `'profanity'`)

* `UNKNOWN` (value: `'unknown'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


